@@ -12,6 +12,7 @@ import numpy as np
 
 from ..grids.base import GridBase
 from ..tools.docstrings import fill_in_docstring
+from ..tools.misc import Number, number_array
 from ..tools.plotting import PlotReference, plot_on_figure
 from .base import DataFieldBase, FieldBase, OptionalArrayLike
 from .scalar import ScalarField
@@ -24,8 +25,10 @@ class FieldCollection(FieldBase):
         self,
         fields: Sequence[DataFieldBase],
         data: OptionalArrayLike = None,
+        *,
         copy_fields: bool = False,
         label: Optional[str] = None,
+        dtype=None,
     ):
         """
         Args:
@@ -39,6 +42,9 @@ class FieldCollection(FieldBase):
                 are copied.
             label (str):
                 Label of the field collection
+            dtype (numpy dtype):
+                The data type of the field. All the numpy dtypes are supported. If
+                omitted, it will be determined from `data` automatically.
 
         Warning:
             If `data` is given and :code:`copy_fields == False`, the data in the
@@ -64,7 +70,7 @@ class FieldCollection(FieldBase):
             self._fields = fields  # type: ignore
 
         # extract data from individual fields
-        new_data: List[np.ndarray] = []
+        fields_data: List[np.ndarray] = []
         self._slices: List[slice] = []
         dof = 0  # count local degrees of freedom
         for field in self.fields:
@@ -73,18 +79,21 @@ class FieldCollection(FieldBase):
                     "Individual fields must be of type DataFieldBase. Field "
                     "collections cannot be nested."
                 )
-            start = len(new_data)
+            start = len(fields_data)
             this_data = field._data_flat
-            new_data.extend(this_data)
-            self._slices.append(slice(start, len(new_data)))
+            fields_data.extend(this_data)
+            self._slices.append(slice(start, len(fields_data)))
             dof += len(this_data)
 
         # combine into one data field
         data_shape = (dof,) + grid.shape
         if data is None:
-            data_arr = np.array(new_data, dtype=np.double)
+            # the data is taken from the individual fields
+            data_arr = number_array(fields_data, dtype=dtype, copy=False)
+
         else:
-            data_arr = np.asarray(data, dtype=np.double)
+            # the data is taken from the supplied data argument
+            data_arr = number_array(data, dtype=dtype, copy=False)
             if data_arr.shape != data_shape:
                 data_arr = np.array(np.broadcast_to(data_arr, data_shape))
         assert data_arr.shape == data_shape
@@ -267,8 +276,10 @@ class FieldCollection(FieldBase):
         cls,
         grid: GridBase,
         expressions: Sequence[str],
+        *,
         label: str = None,
         labels: Optional[Sequence[str]] = None,
+        dtype=None,
     ) -> "FieldCollection":
         """create a field collection on a grid from given expressions
 
@@ -285,9 +296,12 @@ class FieldCollection(FieldBase):
                 standard mathematical functions and they may depend on the axes
                 labels of the grid.
             label (str, optional):
-                Name of the field
+                Name of the whole collection
             labels (list of str, optional):
                 Names of the individual fields
+            dtype (numpy dtype):
+                The data type of the field. All the numpy dtypes are supported. If
+                omitted, it will be determined from `data` automatically.
         """
         if isinstance(expressions, str):
             expressions = [expressions]
@@ -296,7 +310,7 @@ class FieldCollection(FieldBase):
 
         # evaluate all expressions at all points
         fields = [
-            ScalarField.from_expression(grid, expression, labels[i])
+            ScalarField.from_expression(grid, expression, label=labels[i], dtype=dtype)
             for i, expression in enumerate(expressions)
         ]
 
@@ -377,7 +391,7 @@ class FieldCollection(FieldBase):
         return results
 
     def copy(
-        self, data: OptionalArrayLike = None, label: str = None
+        self, data: OptionalArrayLike = None, *, label: str = None, dtype=None
     ) -> "FieldCollection":
         """return a copy of the data, but not of the grid
 
@@ -387,6 +401,9 @@ class FieldCollection(FieldBase):
                 field. Note that the data is not copied but used directly.
             label (str, optional):
                 Name of the copied field
+            dtype (numpy dtype):
+                The data type of the field. If omitted, it will be determined from
+                `data` automatically.
         """
         if label is None:
             label = self.label
@@ -394,13 +411,15 @@ class FieldCollection(FieldBase):
         # if data is None, the data of the individual fields is copied in their
         # copy() method above. The underlying data is therefore independent from
         # the current field
-        return self.__class__(fields, data=data, label=label, copy_fields=False)
+        return self.__class__(
+            fields, data=data, copy_fields=False, label=label, dtype=dtype
+        )
 
     def interpolate_to_grid(
         self,
         grid: GridBase,
         method: str = "numba",
-        fill: float = None,
+        fill: Number = None,
         label: Optional[str] = None,
     ) -> "FieldCollection":
         """interpolate the data of this field collection to another grid.
@@ -412,7 +431,7 @@ class FieldCollection(FieldBase):
             method (str):
                 Specifies interpolation method, e.g., 'numba', 'scipy_linear',
                 'scipy_nearest' .
-            fill (float, optional):
+            fill (Number, optional):
                 Determines how values out of bounds are handled. If `None`, a
                 `ValueError` is raised when out-of-bounds points are requested.
                 Otherwise, the given value is returned.
@@ -431,7 +450,7 @@ class FieldCollection(FieldBase):
 
     def smooth(
         self,
-        sigma: Optional[float] = 1,
+        sigma: float = 1,
         out: Optional["FieldCollection"] = None,
         label: str = None,
     ) -> "FieldCollection":
@@ -440,7 +459,7 @@ class FieldCollection(FieldBase):
         This function respects periodic boundary conditions of the underlying
         grid, using reflection when no periodicity is specified.
 
-        sigma (float, optional):
+        sigma (float):
             Gives the standard deviation of the smoothing in real length units
             (default: 1)
         out (FieldCollection, optional):
