@@ -20,7 +20,7 @@ from .base import DimensionError, GridBase, _check_shape, discretize_interval
 from .cartesian import CartesianGrid
 
 if TYPE_CHECKING:
-    from .boundaries import Boundaries  # @UnusedImport
+    from .boundaries.axes import Boundaries  # @UnusedImport
 
 
 PI_4 = 4 * np.pi
@@ -95,7 +95,7 @@ class SphericalGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equals
         return self.axes_bounds[0][0] > 0
 
     @classmethod
-    def from_state(cls, state) -> "SphericalGridBase":
+    def from_state(cls, state: Dict[str, Any]) -> "SphericalGridBase":  # type: ignore
         """create a field from a stored `state`.
 
         Args:
@@ -135,11 +135,11 @@ class SphericalGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equals
         volumes_l = volume_from_radius(rs - 0.5 * dr, dim=self.dim)
         return ((volumes_h - volumes_l).reshape(self.shape[0]),)  # type: ignore
 
-    def contains_point(self, point):
+    def contains_point(self, point: np.ndarray) -> np.ndarray:
         """check whether the point is contained in the grid
 
         Args:
-            point (vector): Coordinates of the point
+            point (:class:`numpy.ndarray`): Coordinates of the point
         """
         point = np.atleast_1d(point)
         if point.shape[-1] != self.dim:
@@ -154,7 +154,7 @@ class SphericalGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equals
         boundary_distance: float = 0,
         cartesian: bool = True,
         avoid_center: bool = False,
-    ):
+    ) -> np.ndarray:
         """return a random point within the grid
 
         Note that these points will be uniformly distributed on the radial axis,
@@ -189,7 +189,7 @@ class SphericalGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equals
         else:
             return r
 
-    def get_line_data(self, data, extract: str = "auto") -> Dict[str, Any]:
+    def get_line_data(self, data: np.ndarray, extract: str = "auto") -> Dict[str, Any]:
         """return a line cut along the radial axis
 
         Args:
@@ -216,7 +216,7 @@ class SphericalGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equals
 
     def get_image_data(
         self,
-        data,
+        data: np.ndarray,
         performance_goal: str = "speed",
         fill_value: float = 0,
         masked: bool = True,
@@ -287,7 +287,7 @@ class SphericalGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equals
         }
 
     def iter_mirror_points(
-        self, point, with_self: bool = False, only_periodic: bool = True
+        self, point: np.ndarray, with_self: bool = False, only_periodic: bool = True
     ) -> Generator:
         """generates all mirror points corresponding to `point`
 
@@ -303,29 +303,7 @@ class SphericalGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equals
         if with_self:
             yield point
 
-    def normalize_point(self, point, reduced_coords: bool = False):
-        """normalize coordinates, which is a no-op for spherical coordinates.
-
-        Args:
-            point (:class:`numpy.ndarray`): Coordinates of a single point
-            reduced_coords (bool): Flag determining whether only the coordinates
-                corresponding to axes in this grid are given
-
-        Returns:
-            :class:`numpy.ndarray`: The input array
-        """
-        point = np.asarray(point, dtype=np.double)
-        size = self.num_axes if reduced_coords else self.dim
-        if point.size == 0:
-            return np.zeros((0, size))
-        if point.shape[-1] != size:
-            raise DimensionError(
-                f"Dimension mismatch: Array of shape {point.shape} does not describe "
-                f"points of dimension {size}"
-            )
-        return point
-
-    def point_from_cartesian(self, points):
+    def point_from_cartesian(self, points: np.ndarray) -> np.ndarray:
         """convert points given in Cartesian coordinates to this grid
 
         Args:
@@ -335,10 +313,11 @@ class SphericalGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equals
         Returns:
             :class:`numpy.ndarray`: Points given in the coordinates of the grid
         """
-        points = self.normalize_point(points)
+        points = np.atleast_1d(points)
+        assert points.shape[-1] == self.dim
         return np.linalg.norm(points, axis=-1, keepdims=True)
 
-    def cell_to_point(self, cells, cartesian: bool = True):
+    def cell_to_point(self, cells: np.ndarray, cartesian: bool = True) -> np.ndarray:
         """convert cell coordinates to real coordinates
 
         This function returns points restricted to the x-axis, i.e., the
@@ -357,6 +336,8 @@ class SphericalGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equals
             :class:`numpy.ndarray`: The center points of the respective cells
         """
         cells = np.atleast_1d(cells)
+        assert cells.shape[-1] == self.num_axes
+
         # convert from cells indices to grid coordinates
         r_inner, _ = self.axes_bounds[0]
         points = r_inner + (cells + 0.5) * self.discretization[0]
@@ -365,13 +346,9 @@ class SphericalGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equals
         else:
             return points
 
-    def point_to_cell(self, points):
+    def point_to_cell(self, points: np.ndarray) -> np.ndarray:
         """Determine cell(s) corresponding to given point(s)
 
-        This function respects periodic boundary conditions, but it does not
-        throw an error when coordinates lie outside the bcs (for
-        non-periodic axes).
-
         Args:
             points (:class:`numpy.ndarray`): Real coordinates
 
@@ -379,12 +356,12 @@ class SphericalGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equals
             :class:`numpy.ndarray`: The indices of the respective cells
         """
         # convert from grid coordinates to cells indices
-        r_inner, _ = self.axes_bounds[0]
         r = self.point_from_cartesian(points)
+        r_inner, _ = self.axes_bounds[0]
         cells = (r - r_inner) / self.discretization[0]
         return cells.astype(np.int)
 
-    def difference_vector_real(self, p1, p2):
+    def difference_vector_real(self, p1: np.ndarray, p2: np.ndarray) -> np.ndarray:
         """return the vector pointing from p1 to p2.
 
         In case of periodic boundary conditions, the shortest vector is returned
@@ -403,7 +380,7 @@ class SphericalGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equals
         """return spherical coordinates associated with the grid
 
         Args:
-            origin (vector): Coordinates of the origin at which the polar
+            origin (:class:`numpy.ndarray`): Coordinates of the origin at which the polar
                 coordinate system is anchored. Note that this must be of the
                 form `[0, 0, z_val]`, where only `z_val` can be chosen freely.
             ret_angle (bool): Determines whether angles are returned alongside
@@ -471,7 +448,7 @@ class SphericalGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equals
                 bcs = Boundaries.from_data(self, bc, rank=rank)
             else:
                 self._logger.warning(
-                    "The inner boundary condition was not specified. We assume a "
+                    "The inner boundary condition was not specified. Assuming a "
                     "vanishing derivative at r=0."
                 )
                 b_inner = NeumannBC(self, 0, upper=False, rank=rank)
@@ -533,7 +510,7 @@ class PolarGrid(SphericalGridBase):
     axes_symmetric = ["phi"]
     coordinate_constraints = [0, 1]  # axes not described explicitly
 
-    def point_to_cartesian(self, points):
+    def point_to_cartesian(self, points: np.ndarray) -> np.ndarray:
         """convert coordinates of a point to Cartesian coordinates
 
         This function returns points along the y-coordinate, i.e, the x
@@ -543,8 +520,8 @@ class PolarGrid(SphericalGridBase):
             :class:`numpy.ndarray`: The Cartesian coordinates of the point
         """
         points = np.atleast_1d(points)
-        if points.shape[-1] != 1:
-            raise DimensionError(f"Dimension mismatch: Points {points} invalid")
+        if points.shape[-1] != self.num_axes:
+            raise DimensionError(f"Shape {points.shape} cannot denote points")
 
         y = points[..., 0]
         x = np.zeros_like(y)
@@ -601,7 +578,7 @@ class SphericalGrid(SphericalGridBase):
     axes_symmetric = ["theta", "phi"]
     coordinate_constraints = [0, 1, 2]  # axes not described explicitly
 
-    def point_to_cartesian(self, points):
+    def point_to_cartesian(self, points: np.ndarray) -> np.ndarray:
         """convert coordinates of a point to Cartesian coordinates
 
         This function returns points along the z-coordinate, i.e, the x and y
@@ -615,8 +592,8 @@ class SphericalGrid(SphericalGridBase):
             :class:`numpy.ndarray`: The Cartesian coordinates of the point
         """
         points = np.atleast_1d(points)
-        if points.shape[-1] != 1:
-            raise DimensionError(f"Dimension mismatch: Points {points} invalid")
+        if points.shape[-1] != self.num_axes:
+            raise DimensionError(f"Shape {points.shape} cannot denote points")
         z = points[..., 0]
         x = np.zeros_like(z)
         return np.stack((x, x, z), axis=-1)
