@@ -103,7 +103,7 @@ class KPZInterfacePDE(PDEBase):
             the evolution rate.
         """
         shape = state.grid.shape
-        arr_type = nb.typeof(np.empty(shape, dtype=np.double))
+        arr_type = nb.typeof(np.empty(shape, dtype=state.data.dtype))
         signature = arr_type(arr_type, nb.double)
 
         nu_value, lambda_value = self.nu, self.lmbda
